/*

  Radiosity trick: loading data saved from a dummy and small render.

  Sept-2002
 
  POV-Ray 3.50a

  The acompainign images illustrate the test: the dummy scene, rendered at only
  320x240 pixels, took 818s to complete. Then, a final render was done at 600x450,
  and it only took 618s. A true final render using directly the radiosity settings 
  used for the dummy scene was not traced, because it used more than 30min to complete 
  half of the pre_trace steps.

  --
  Jaime Vives Piqueres
  http://www.ignorancia.org

*/
#version 3.5;

#include "colors.inc"
#include "textures.inc"
#include "functions.inc"

#declare use_rad=0;  // radiosity: 0=no rad, 1=load, 2=save
#declare use_ftx=0;  // textures: 0=test, 1=final
#declare use_geo=0;  // geometry: 0=dummy, 1=final

global_settings{
 assumed_gamma 1.0
 ambient_light 0.0 
 #if (use_rad)
 radiosity{ 
  // save settings: modified Outdoor settings from rad_def.inc
  #if (use_rad=2) 
    pretrace_start 0.08
    pretrace_end   0.01
    count 250
    nearest_count 20
    error_bound 0.1
    recursion_limit 2
    low_error_factor .9
    gray_threshold 0
    minimum_reuse 0.015
    brightness 1.0
    adc_bailout 0.01/2
    save_file "rad-save-load.rad"
  #else
    // load settings  
    pretrace_start 1 pretrace_end 1 
    load_file "rad-save-load.rad" 
    error_bound 0.1    // it's important to specify the same value used to save data
    recursion_limit 2  // also the same if specified
    always_sample off  // no more samples: specially useful with focal blur
  #end
 }
 #end
}



// *********************
// *** TEST SCENARIO ***
// *********************
#declare r_side=seed(6734);

// concrete block
#macro concrete_block()

  #if (use_geo)  // isosurface for final render
    #local kk=rand(r_side);
    isosurface{
     function{f_rounded_box(x,y,z,.04,1,1,1) + f_granite(x+10*kk,y,z)*.015}
     max_gradient 1.2
     contained_by{box{-1,1}}
     scale .5
  #else          // a box only for the dummy render
    box{-.5,.5
  #end
  #if (use_ftx)  // complex textures for the final render
     texture{
      pigment{cells color_map{[0 Wheat][1 White*.9]} scale .2 turbulence 1}
      #if (rand(r_side)<.5)
        rotate 180*z
      #end
      translate <rand(r_side),rand(r_side),rand(r_side)>
     }
     texture{
      pigment{
       boxed turbulence .1 lambda 4
       color_map{
        [0.0 Gray10 transmit .5]
        [0.2 rgbt 1]
        [1.0 rgbt 1]
       }
      scale <.5,.5,1>
      translate (-.4+.8*rand(r_side))*z
      }
     }
     texture{
      pigment{
       function{abs(y)} turbulence .3 lambda 4
       color_map{
        [0.0 Gray10 transmit .6]
        [0.2 rgbt 1]
        [0.5 Gray10 transmit .9]
        [1.0 rgbt 1]
       }
      scale <.01,1.2,.01> translate .3*y
      translate (-.5+rand(r_side))*z
      }
     }
   #else      // a simple pigment for the dummy render
     texture{
      pigment{Gray90}
     }
   #end
    scale 100
    translate 50*y
   }

#end  // of concrete block macro

// *** place som blocks here and there ***
object{concrete_block()}
object{concrete_block() translate <   0,  0,-100>}
object{concrete_block() translate <-100,  0,   0>}
object{concrete_block() translate <-200,  0,   0>}
object{concrete_block() translate <-200,  0,-100>}
object{concrete_block() translate <-200,  0,-200>}
object{concrete_block() translate <-200,  0,-300>}
object{concrete_block() translate <-200,  0,-400>}
object{concrete_block() translate < 100,  0,   0>}
object{concrete_block() translate < 200,  0,   0>}
object{concrete_block() translate < 200,  0,-100>}
object{concrete_block() translate < 300,  0,-100>}
object{concrete_block() translate < 300,  0,-200>}
object{concrete_block() translate < 300,  0,-300>}
object{concrete_block() translate < 300,100,-200>}
object{concrete_block() translate <-100,100,   0>}
object{concrete_block() translate <-200,100,   0>}
object{concrete_block() translate <-200,100,-200>}
object{concrete_block() translate <-200,100,-400>}
object{concrete_block() translate <   0,100, 50>}
object{concrete_block() translate < 100,100,   0>}
object{concrete_block() translate < 200,100,   0>}
object{concrete_block() translate < 200,100,-100>}
object{concrete_block() translate <-100,100,-700>}
object{concrete_block() translate < 300,100,-500>}
object{concrete_block() translate <   0,200,-100>}
object{concrete_block() translate <   0,200,   0>}
object{concrete_block() translate <-100,200,   0>}
object{concrete_block() translate <-200,200,   0>}
object{concrete_block() translate <-200,200,-200>}
object{concrete_block() translate <-200,200,-400>}
object{concrete_block() translate < 100,200,   0>}
object{concrete_block() translate < 200,200,   0>}
object{concrete_block() translate <-100,200,-700>}
object{concrete_block() translate < 200,300,   0>}
object{concrete_block() translate <-100,300,   0>}
object{concrete_block() translate <-200,300,   0>}
object{concrete_block() translate <-200,300,-200>}
object{concrete_block() translate <-200,300,-400>}
object{concrete_block() translate < 200,400,   0>}
object{concrete_block() translate <-200,400,   0>}
object{concrete_block() translate <-200,400,-100>}
object{concrete_block() translate <-200,400,-200>}
object{concrete_block() translate <-200,400,-300>}
object{concrete_block() translate <-200,400,-400>}
object{concrete_block() translate <-200,  0,-500>}
object{concrete_block() translate <-200,  0,-600>}
object{concrete_block() translate <-200,  0,-700>}
object{concrete_block() translate <-100,  0,-700>}
object{concrete_block() translate < 200,  0,-700>}
object{concrete_block() translate < 300,  0,-700>}
object{concrete_block() translate < 300,  0,-600>}
object{concrete_block() translate < 300,  0,-500>}

// *** add some floor ***
plane{y,0
 #if (use_ftx)
 pigment{
  bozo
  color_map{
   [0 Flesh]
   [0.5 White]
   [1 Gray10]
  }
  warp{turbulence 1 lambda 4}
  scale 100
 }
 #else
 pigment{White*.9}
 #end
}

// *** and the typical chromed sphere ***
sphere{0,1
 scale 30
 #if (use_ftx)
 texture{Polished_Chrome}
 #else
 pigment{White}
 #end
 translate <0,130,-50>
}

// *** finally a sky sphere ***
sphere{0,15000
 pigment{SummerSky*.75+White*.25}
}

// *** and the sunlight ***
light_source{
 <0,10000,0>
 White+Gold
 fade_distance 20000
 fade_power 2
 rotate <-50,60,0>
}

// +** take a frontal shot ***
camera{
 location <10,150,-800>
// location <10,1500,-2100>
 direction 2.5*z
 look_at <0,100,0>
}
